@@ -13,7 +13,7 @@ from scipy import exp, log
 from scipy.optimize import fsolve
 
 from ._iapws import _fase
-from ._iapws import _Viscosity, _ThCond, _Dielectric, _Refractive
+from ._iapws import _Viscosity, _ThCond, _Dielectric, _Refractive, _Tension
 from .iapws97 import _TSat_P
 
 
@@ -136,7 +136,7 @@ class MEoS(_fase):
     def __call__(self, **kwargs):
         """Make instance callable to can add input parameter one to one"""
         if kwargs.get("v", 0):
-            kwargs["rho"] = kwargs["v"]
+            kwargs["rho"] = 1./kwargs["v"]
             del kwargs["v"]
         self.kwargs.update(kwargs)
 
@@ -151,7 +151,7 @@ class MEoS(_fase):
         self._mode = ""
         if self.kwargs["T"] and self.kwargs["P"]:
             self._mode = "TP"
-        elif self.kwargs["T"] and (self.kwargs["rho"] or self.kwargs["v"]):
+        elif self.kwargs["T"] and self.kwargs["rho"]:
             self._mode = "Trho"
         elif self.kwargs["T"] and self.kwargs["h"] is not None:
             self._mode = "Th"
@@ -159,7 +159,7 @@ class MEoS(_fase):
             self._mode = "Ts"
         elif self.kwargs["T"] and self.kwargs["u"] is not None:
             self._mode = "Tu"
-        elif self.kwargs["P"] and (self.kwargs["rho"] or self.kwargs["v"]):
+        elif self.kwargs["P"] and self.kwargs["rho"]:
             self._mode = "Prho"
         elif self.kwargs["P"] and self.kwargs["h"] is not None:
             self._mode = "Ph"
@@ -167,11 +167,11 @@ class MEoS(_fase):
             self._mode = "Ps"
         elif self.kwargs["P"] and self.kwargs["u"] is not None:
             self._mode = "Pu"
-        elif (self.kwargs["rho"] or self.kwargs["v"]) and self.kwargs["h"] is not None:
+        elif self.kwargs["rho"] and self.kwargs["h"] is not None:
             self._mode = "rhoh"
-        elif (self.kwargs["rho"] or self.kwargs["v"]) and self.kwargs["s"] is not None:
+        elif self.kwargs["rho"] and self.kwargs["s"] is not None:
             self._mode = "rhos"
-        elif (self.kwargs["rho"] or self.kwargs["v"]) and self.kwargs["u"] is not None:
+        elif self.kwargs["rho"] and self.kwargs["u"] is not None:
             self._mode = "rhou"
         elif self.kwargs["h"] is not None and self.kwargs["s"] is not None:
             self._mode = "hs"
@@ -474,6 +474,7 @@ class MEoS(_fase):
             elif x == 1:
                 propiedades = vapor
 
+
         self.T = T
         self.Tr = T/self.Tc
         self.P = P
@@ -510,8 +511,11 @@ class MEoS(_fase):
             self.IntP = x*self.Gas.IntP+(1-x)*self.Liquid.IntP
 
         # Calculate special properties useful only for one phase
-        if x < 1 and self.Tt <= T <= self.Tc:
-            self.sigma = self._Tension(T)
+        if self._mode in ("Px", "Tx") or (x < 1 and self.Tt <= T <= self.Tc):
+            if self.name == "water":
+                self.sigma = _Tension(T)
+            else:
+                self.sigma = self._Tension(T)
         else:
             self.sigma = None
 
@@ -1166,7 +1170,6 @@ class IAPWS95(MEoS):
         "A": [0.32, .32],
         "beta4": [0.3, 0.3]}
 
-    _surface = {"sigma": [0.2358, -0.147375], "exp": [1.256, 2.256]}
     _vapor_Pressure = {
         "eq": 6,
         "ao": [-7.85951783, 1.84408259, -11.7866497, 22.6807411, -15.9618719,
